@@ -13,8 +13,10 @@ package #hide from PAUSE
   DBIx::Class::Migration::_Types;
 
 use MooseX::Types::LoadableClass 'LoadableClass';
-use MooseX::Types::Moose 'Str', 'ClassName';
-use MooseX::Types -declare => [ 'LoadableDBICSchemaClass' ];
+use MooseX::Types::Moose 'Str', 'ClassName', 'ArrayRef';
+use MooseX::Types -declare => [ 'LoadableDBICSchemaClass', 'SQLTProducer', 'ArraySQLTProducers' ];
+use Module::Find ();
+use MooseX::Getopt::OptionTypeMap ();
 
 subtype LoadableDBICSchemaClass,
   as LoadableClass,
@@ -24,6 +26,28 @@ coerce LoadableDBICSchemaClass,
   from Str,
   via { to_LoadableClass($_); $_ };
 
+my $sqltp = 'SQL::Translator::Producer';
+subtype SQLTProducer,
+  as Str,
+  where { eval "require $sqltp\::$_; 1" },
+  ;
+
+# Despite being declared as an ArrayRef here, it shows its "parent" as Object
+# and not as ArrayRef. Therefore, the natural "parent" chaining in
+# MooseX::Getopt::OptionTypeMap->has_option_type doesn't work right, so
+# we need to declare it manually below with add_option_type_to_map.
+subtype ArraySQLTProducers,
+  as ArrayRef[SQLTProducer],
+  message {
+    join '',
+      "\nUnknown database type among (@$_) try:\n",
+      map {s#$sqltp\::##; "$_\n"} Module::Find::findallmod($sqltp);
+  },
+  ;
+MooseX::Getopt::OptionTypeMap->add_option_type_to_map(
+  ArraySQLTProducers() => '=s@'
+);
+
 1;
 
 =head1 NAME
